@@ -10,6 +10,7 @@ from .insights import Insights
 from . import sp as sponsored_products
 from . import sb as sponsored_brands
 from . import sd as sponsored_display
+from .attribution import Attribution
 
 __all__ = [
     "sp",
@@ -18,6 +19,7 @@ __all__ = [
     "sponsored_products",
     "sponsored_brands",
     "sponsored_display",
+    "Attribution",
     "Profiles",
     "Invoices",
     "Eligibility",
